@@ -1,4 +1,3 @@
-import numpy as np
 import math, logging
 from os.path import exists
 from collections import Counter
@@ -43,12 +42,3 @@ def get_seqinfo(seqfile: str):
     logging.debug(f"charfreq of {seqfile}: A:{char_freq['A']}; C:{char_freq['C']}; G:{char_freq['G']}; T:{char_freq['T']}; n_seq: {n_seq}; total_len: {total_len}")
 
     return n_seq, total_len, char_freq
-
-def generate_matrix(d2s_combinations_list, n_sample):
-    d2s_matrix = np.zeros((n_sample,n_sample),dtype='float')
-    triu = np.triu_indices(n_sample,k=1)
-    tril = np.tril_indices(n_sample, -1)
-    d2s_matrix[triu] = d2s_combinations_list
-    d2s_matrix[tril] = d2s_matrix.T[tril]
-    
-    return d2s_matrix
\ No newline at end of file
